import { render } from 'vike/abort'; /* eslint-disable-line import/extensions */

import { fetchStashByUsernameAndSlug } from '#/src/stashes.js';
import { fetchMovies } from '#/src/movies.js';
import { curateMoviesQuery } from '#/src/web/movies.js';
import { HttpError } from '#/src/errors.js';

export async function onBeforeRender(pageContext) {
	try {
		const stash = await fetchStashByUsernameAndSlug(pageContext.routeParams.username, pageContext.routeParams.stashSlug, pageContext.user);

		const movieResults = await fetchMovies(await curateMoviesQuery({
			...pageContext.urlQuery,
			scope: pageContext.routeParams.scope || 'latest',
			stashId: stash.id,
		}), {
			page: Number(pageContext.routeParams.page) || 1,
			limit: Number(pageContext.urlParsed.search.limit) || 50,
		}, pageContext.user);

		const {
			movies,
			aggActors,
			aggTags,
			aggChannels,
			total,
			limit,
		} = movieResults;

		return {
			pageContext: {
				title: `${stash.name} by ${stash.user.username}`,
				pageProps: {
					stash,
					movies,
					aggActors,
					aggTags,
					aggChannels,
					total,
					limit,
				},
			},
		};
	} catch (error) {
		if (error instanceof HttpError) {
			throw render(error.httpCode, error.message);
		}

		throw error;
	}
}
